@@ -1,19 +1,11 @@
 # -*- coding: utf-8 -*-
 
+from json import dumps, loads
+import unittest
 import struct
 import sys
 import warnings
 
-if sys.version_info < (2, 7):
-    import unittest2 as unittest  # pragma: nocover
-else:
-    import unittest  # pragma: nocover
-
-try:
-    from simplejson import dumps, loads
-except:
-    from json import dumps, loads  # noqa
-
 from six import b as b_, PY3
 from webtest import TestApp
 
